@@ -1,20 +1,21 @@
+use strictures 2;
+
 package Tie::Redis::Candy;
 
 # ABSTRACT: Tie Redis to HashRef or ArrayRef
 
-use strict;
-use warnings;
+use Redis;
 use Tie::Redis::Candy::Hash;
 use Tie::Redis::Candy::Array;
 use Exporter qw(import);
 
-our $VERSION = '1.000';    # VERSION
+our $VERSION = '1.001';    # VERSION
 
 our @EXPORT_OK = qw(redis_hash redis_array);
 
 sub redis_hash {
-    my ( $redis, $prefix, %init ) = @_;
-    tie( my %hash, 'Tie::Redis::Candy::Hash', $redis, $prefix );
+    my ( $redis, $key, %init ) = @_;
+    tie( my %hash, 'Tie::Redis::Candy::Hash', $redis, $key );
     $hash{$_} = delete $init{$_} for keys %init;
     bless( \%hash, 'Tie::Redis::Candy::Hash' );
 }
@@ -40,7 +41,7 @@ Tie::Redis::Candy - Tie Redis to HashRef or ArrayRef
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -48,7 +49,7 @@ version 1.000
     
     my $redis = Redis->new(...);
     
-    my $hashref = redis_hash($redis, $prefix, %initial_values);
+    my $hashref = redis_hash($redis, $key, %initial_values);
     $hashref->{foo} = 'bar';
     
     my $arrayref = redis_array($redis, $listname, @initial_values);
@@ -60,13 +61,17 @@ This module is inspired by L<Tie::Redis> and L<Redis::Hash>/L<Redis::List>.
 
 =head1 FUNCTIONS
 
-=head2 redis_hash ($redis, $prefix, %initial_values);
+=head2 redis_hash ($redis, $key, %initial_values);
 
-C<$redis> must be an instance of L<Redis> or L<AnyEvent::Redis>. C<$prefix> is optional. With prefix, all keys in the hashref will prefixed with C<"$prefix:">. Set to undef when you want use the entire Redis DB as data source.
+C<$redis> must be an instance of L<Redis>. C<$key> is the name of the hash key.
+
+The hash will not cleared at this point, but the initial values are appended.
 
 =head2 redis_array ($redis, $listname, @initial_values);
 
-Behaves similiar to L</redis_hash>, except that C<$listname> is required.
+Behaves similiar to L</redis_hash>, except that a redis array is used.
+
+The array will not cleared at this point, but the initial values are pushed at the B<end> of list.
 
 =head1 SERIALIZATION
 
